export interface InquiryRequestVO {
  /**
   * 主键ID（自增序列）
   */
  id: string | number;

  /**
   * 询价单号（规则：INQ+年月+6位序列）
   */
  inquiryNo: string;

  /**
   * 发起人id
   */
  requesterId: string | number;

  /**
   * 目标物流商ID列表（JSON数组格式，示例：[101,202,303]）
   */
  targetProviders: string | number;

  /**
   * 目的地（存储四级行政编码，如CN310115）
   */
  destination: string;

  /**
   * 运输方式（枚举值：AIR-空运/SEA-海运/LAND-公路/RAIL-铁路）
   */
  transportChannel: string;

  /**
   * 询价状态（状态机：OPEN-开放中/CLOSED-已关闭/COMPLETED-已完成）
   */
  inquiryStatus: string;

  /**
   * 报价截止时间（超过此时限自动关闭询价）
   */
  deadline: string;

  /**
   * 渠道ID（system=dict_code，custom=自定义渠道ID）
   */
  channelId: string | number;

  /**
   * 渠道名称
   */
  channelName: string;

  /**
   * 报价有效的开始日期
   */
  effectiveStartTime: string;

  /**
   * 报价有效的结束日期
   */
  effectiveEndTime: string;

}

export interface InquiryRequestForm extends BaseEntity {
  /**
   * 主键ID（自增序列）
   */
  id?: string | number;

  /**
   * 询价单号（规则：INQ+年月+6位序列）
   */
  inquiryNo?: string;

  /**
   * 发起人id
   */
  requesterId?: string | number;

  /**
   * 目标物流商ID列表（JSON数组格式，示例：[101,202,303]）
   */
  targetProviders?: string | number;

  /**
   * 目的地（存储四级行政编码，如CN310115）
   */
  destination?: string;

  /**
   * 运输方式（枚举值：AIR-空运/SEA-海运/LAND-公路/RAIL-铁路）
   */
  transportChannel?: string;

  /**
   * 询价状态（状态机：OPEN-开放中/CLOSED-已关闭/COMPLETED-已完成）
   */
  inquiryStatus?: string;

  /**
   * 报价截止时间（超过此时限自动关闭询价）
   */
  deadline?: string;

  /**
   * 渠道ID（system=dict_code，custom=自定义渠道ID）
   */
  channelId?: string | number;

  /**
   * 渠道名称
   */
  channelName?: string;

  /**
   * 报价有效的开始日期
   */
  effectiveStartTime?: string;

  /**
   * 报价有效的结束日期
   */
  effectiveEndTime?: string;

}

export interface InquiryRequestQuery extends PageQuery {

  /**
   * 询价单号（规则：INQ+年月+6位序列）
   */
  inquiryNo?: string;

  /**
   * 发起人id
   */
  requesterId?: string | number;

  /**
   * 目标物流商ID列表（JSON数组格式，示例：[101,202,303]）
   */
  targetProviders?: string | number;

  /**
   * 目的地（存储四级行政编码，如CN310115）
   */
  destination?: string;

  /**
   * 运输方式（枚举值：AIR-空运/SEA-海运/LAND-公路/RAIL-铁路）
   */
  transportChannel?: string;

  /**
   * 询价状态（状态机：OPEN-开放中/CLOSED-已关闭/COMPLETED-已完成）
   */
  inquiryStatus?: string;

  /**
   * 报价截止时间（超过此时限自动关闭询价）
   */
  deadline?: string;

  /**
   * 渠道ID（system=dict_code，custom=自定义渠道ID）
   */
  channelId?: string | number;

  /**
   * 渠道名称
   */
  channelName?: string;

  /**
   * 报价有效的开始日期
   */
  effectiveStartTime?: string;

  /**
   * 报价有效的结束日期
   */
  effectiveEndTime?: string;

    /**
     * 日期范围参数
     */
    params?: any;
}



